@@ -1,6 +1,5 @@
-from typing import Dict, List
-
 from datetime import datetime
+from typing import Dict, List, Union
 
 import dash_bootstrap_components as dbc
 import dash_core_components as dcc
@@ -12,17 +11,17 @@ import card_live_dashboard.layouts.figures as figures
 
 external_stylesheets = [dbc.themes.BOOTSTRAP]
 
+LOADING = '[LOADING]'
+
 
 def default_layout():
     """
     Builds the default layout of the CARD:Live dashboard.
     :return: The default layout of the CARD:Live dashboard.
     """
-    LOADING = '[LOADING]'
-
     layout = html.Div(className='card-live-all container-fluid', children=[
         html.Div(className='row', children=[
-            html.Div(className='card-live-panel col-sm-3', children=[
+            html.Div(className='card-live-panel col-lg-3', children=[
                 html.Div(className='sticky-top', children=[
                     html.H1([
                         'CARD:Live'
@@ -30,7 +29,10 @@ def default_layout():
                     html.Div(className='pt-2 pb-1', children=[
                         'Welcome to the ',
                         html.A(children=['CARD:Live'], href='https://card.mcmaster.ca/live'),
-                        ' dashboard.'
+                        ' dashboard. This provides summaries of detected antimicrobial resistance for user-submitted',
+                        ' genomic samples to the online ',
+                        html.A(children=['RGI tool'], href='https://card.mcmaster.ca/analyze/rgi'),
+                        '.',
                     ]),
                     html.Div(className='card-live-badges pb-3', children=[
                         html.Span(className='badge badge-secondary', children=[
@@ -38,14 +40,12 @@ def default_layout():
                             ' samples']),
                         ' ',
                         html.Span(className='badge badge-secondary',
-                                  children=[f'Most recent: ', html.Span(id='global-most-recent', children=[LOADING])]),
+                                  children=['Most recent: ', html.Span(id='global-most-recent', children=[LOADING])]),
                     ]),
                     html.Div([
                         html.H2('Selection criteria'),
                         html.P([
-                            'Please select from the options below to examine subsets of the ',
-                            html.A(children=['CARD:Live'], href='https://card.mcmaster.ca/live'),
-                            ' data.',
+                            'Please select from the options below to examine subsets of the samples.',
                             html.Div(className='card-live-badges pt-1', children=[
                                 html.Span(className='badge badge-secondary', children=[
                                     'Showing ', html.Span(id='selected-samples-count',
@@ -57,9 +57,12 @@ def default_layout():
                     ]),
                     html.Div([
                         dbc.Button(id='rgi-parameters-toggle', color='link',
-                                   className='cardlive-collapse pl-0', children=[html.H3('RGI')]),
+                                   className='cardlive-collapse pl-0', children=[
+                                       html.H3(className='sidebar-title', children=['RGI']),
+                                       html.Span(className='sidebar-description', children=['Filter by RGI results']),
+                                   ]),
                         dbc.Collapse(id='rgi-parameters', is_open=True, children=[
-                            html.Div(children=['RGI cutoff: ',
+                            html.Div(children=['RGI results cutoff: ',
                                                dbc.RadioItems(
                                                    id='rgi-cutoff-select',
                                                    className='sidepanel-selection-light',
@@ -72,7 +75,7 @@ def default_layout():
                                                    inline=True,
                                                ),
                                                ]),
-                            html.Div(children=['Filter display by drug class: ',
+                            html.Div(children=['Filter samples by drug class: ',
                                                dcc.Dropdown(
                                                    id='drug-class-select',
                                                    className='sidepanel-selection',
@@ -80,7 +83,7 @@ def default_layout():
                                                    placeholder='Select a drug class',
                                                ),
                                                ]),
-                            html.Div(children=['Filter display by AMR gene family: ',
+                            html.Div(children=['Filter samples by AMR gene family: ',
                                                dcc.Dropdown(
                                                    id='amr-gene-family-select',
                                                    className='sidepanel-selection',
@@ -88,7 +91,7 @@ def default_layout():
                                                    placeholder='Select the AMR gene family',
                                                ),
                                                ]),
-                            html.Div(children=['Filter display by resistance mechanism: ',
+                            html.Div(children=['Filter samples by resistance mechanism: ',
                                                dcc.Dropdown(
                                                    id='resistance-mechanism-select',
                                                    className='sidepanel-selection',
@@ -96,7 +99,7 @@ def default_layout():
                                                    placeholder='Select the resistance mechanism',
                                                ),
                                                ]),
-                            html.Div(children=['Filter display by AMR gene: ',
+                            html.Div(children=['Filter samples by AMR gene: ',
                                                dcc.Dropdown(
                                                    id='amr-gene-select',
                                                    className='sidepanel-selection',
@@ -108,9 +111,12 @@ def default_layout():
                     ]),
                     html.Div([
                         dbc.Button(id='organism-parameters-toggle', color='link',
-                                   className='cardlive-collapse pl-0', children=[html.H3('Organism')]),
+                                   className='cardlive-collapse pl-0', children=[
+                                       html.H3(className='sidebar-title', children=['Organism']),
+                                       html.Span(className='sidebar-description', children=['Filter by organism']),
+                                   ]),
                         dbc.Collapse(id='organism-parameters', is_open=True, children=[
-                            html.Div(children=['Select an organism identification method: ',
+                            html.Div(children=['Organism identification method: ',
                                                dbc.RadioItems(
                                                    id='organism-identification-method',
                                                    className='sidepanel-selection-light',
@@ -132,9 +138,12 @@ def default_layout():
                     ]),
                     html.Div([
                         dbc.Button(id='time-parameters-toggle', color='link',
-                                   className='cardlive-collapse pl-0', children=[html.H3('Time')]),
+                                   className='cardlive-collapse pl-0', children=[
+                                       html.H3(className='sidebar-title', children=['Time']),
+                                       html.Span(className='sidebar-description', children=['Filter by submission time']),
+                                   ]),
                         dbc.Collapse(id='time-parameters', is_open=True, children=[
-                            html.Div(children=['Select a time period: ',
+                            html.Div(children=['Filter by submission time period: ',
                                                dcc.Dropdown(id='time-period-items',
                                                             className='sidepanel-selection',
                                                             value='all',
@@ -154,7 +163,7 @@ def default_layout():
                                                        number_of_months_shown=2,
                                                    ),
                                                ])
-                                           ]),
+                                               ]),
                         ]),
                     ]),
                     html.P(className='text-center card-live-badges pb-5', children=[
@@ -164,7 +173,7 @@ def default_layout():
                                href='https://github.com/arpcard/card-live-dashboard/releases'),
                         html.Br(),
                         html.A(className='badge badge-primary my-1',
-                               children=[f'Code and Docs | GitHub'],
+                               children=['Code and Docs | GitHub'],
                                href='https://github.com/arpcard/card-live-dashboard')
                     ]),
                     html.Div(className='py-5')
@@ -196,31 +205,34 @@ def figures_layout(figures_dict: Dict[str, go.Figure]):
     return [
         html.Div(className='cardlive-figures', children=[
             single_figure_layout(title='Map',
+                                 description=['Geographic distribution of the submitted genomic samples.'],
                                  id='figure-geographic-map-id',
                                  fig=figures_dict['map']
                                  ),
             single_figure_layout(title='Samples timeline',
+                                 description=['Submission dates for genomic samples.'],
                                  id='figure-timeline-id',
                                  fig=figures_dict['timeline'],
                                  dropdowns=figure_menus_layout(
                                      id_type='timeline-type-select',
                                      options_type=[
-                                        {'label': 'Cumulative counts', 'value': 'cumulative_counts'},
-                                        {'label': 'Cumulative percent', 'value': 'cumulative_percent'},
-                                        {'label': 'Counts', 'value': 'counts'},
-                                        {'label': 'Percent', 'value': 'percent'},
+                                         {'label': 'Cumulative counts', 'value': 'cumulative_counts'},
+                                         {'label': 'Cumulative percent', 'value': 'cumulative_percent'},
+                                         {'label': 'Counts', 'value': 'counts'},
+                                         {'label': 'Percent', 'value': 'percent'},
                                      ],
                                      value_type='cumulative_counts',
                                      id_color='timeline-color-select',
                                      options_color=[
-                                        {'label': 'Default', 'value': 'default'},
-                                        {'label': 'Geographic region', 'value': 'geographic'},
-                                        {'label': 'Organism', 'value': 'organism'},
+                                         {'label': 'Default', 'value': 'default'},
+                                         {'label': 'Geographic region', 'value': 'geographic'},
+                                         {'label': 'Organism', 'value': 'organism'},
                                      ],
                                      value_color='default'
                                  ),
-                             ),
+                                 ),
             single_figure_layout(title='Samples total',
+                                 description=['Count of samples matching selection.'],
                                  id='figure-totals-id',
                                  fig=figures_dict['totals'],
                                  dropdowns=figure_menus_layout(
@@ -238,8 +250,12 @@ def figures_layout(figures_dict: Dict[str, go.Figure]):
                                      ],
                                      value_color='default'
                                  ),
-                             ),
+                                 ),
             single_figure_layout(title='RGI results',
+                                 description=['Percent of selected samples (',
+                                              html.Span(id='sample-count-figure', children=[LOADING]),
+                                              ') with the chosen type of RGI results.'
+                                              ],
                                  id='figure-rgi-id',
                                  fig=figures_dict['rgi'],
                                  dropdowns=figure_menus_layout(
@@ -259,15 +275,17 @@ def figures_layout(figures_dict: Dict[str, go.Figure]):
                                      ],
                                      value_color='default'
                                  ),
-                             ),
+                                 ),
         ])
     ]
 
 
-def single_figure_layout(title: str, id: str, fig: go.Figure, dropdowns: html.Div = None):
+def single_figure_layout(title: str, description: List[Union[str, html.Span]], id: str, fig: go.Figure,
+                         dropdowns: html.Div = None):
     component = dbc.Card(className='my-3', children=[
         dbc.CardHeader(children=[
-            html.H4(title),
+            html.H4(className='figure-title', children=[title]),
+            html.Span(className='figure-description', children=description),
             dropdowns,
         ]),
         dcc.Loading(type='circle', children=[
@@ -280,8 +298,9 @@ def single_figure_layout(title: str, id: str, fig: go.Figure, dropdowns: html.Di
     return component
 
 
-def figure_menus_layout(id_type: str, options_type: List[Dict[str,str]], value_type: str,
-                        id_color: str = None, options_color: List[Dict[str,str]] = None, value_color: str = None) -> html.Div:
+def figure_menus_layout(id_type: str, options_type: List[Dict[str, str]], value_type: str,
+                        id_color: str = None, options_color: List[Dict[str, str]] = None,
+                        value_color: str = None) -> html.Div:
     elements = [html.Div(['Type:']), html.Div(className='ml-2', children=[dcc.Dropdown(
         id=id_type,
         options=options_type,
